@@ -1,10 +1,8 @@
-from __future__ import annotations
-
 from contextlib import contextmanager
 from dataclasses import dataclass
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Optional, Union
 
-from sqlspec.base import GenericDatabaseConfig, NoPoolConfig
+from sqlspec.base import NoPoolSyncConfig
 from sqlspec.typing import Empty, EmptyType
 
 if TYPE_CHECKING:
@@ -17,25 +15,22 @@ __all__ = ("AdbcDatabaseConfig",)
 
 
 @dataclass
-class AdbcDatabaseConfig(NoPoolConfig["Connection"], GenericDatabaseConfig):
+class AdbcDatabaseConfig(NoPoolSyncConfig["Connection"]):
     """Configuration for ADBC connections.
 
     This class provides configuration options for ADBC database connections using the
     ADBC Driver Manager.([1](https://arrow.apache.org/adbc/current/python/api/adbc_driver_manager.html))
     """
 
-    __supports_connection_pooling = False
-    __is_async = False
-
-    uri: str | EmptyType = Empty
+    uri: "Union[str, EmptyType]" = Empty
     """Database URI"""
-    driver_name: str | EmptyType = Empty
+    driver_name: "Union[str, EmptyType]" = Empty
     """Name of the ADBC driver to use"""
-    db_kwargs: dict[str, Any] | None = None
+    db_kwargs: "Optional[dict[str, Any]]" = None
     """Additional database-specific connection parameters"""
 
     @property
-    def connection_params(self) -> dict[str, Any]:
+    def connection_params(self) -> "dict[str, Any]":
         """Return the connection parameters as a dict."""
         return {
             k: v
@@ -44,7 +39,7 @@ class AdbcDatabaseConfig(NoPoolConfig["Connection"], GenericDatabaseConfig):
         }
 
     @contextmanager
-    def provide_connection(self, *args: Any, **kwargs: Any) -> Generator[Connection, None, None]:
+    def provide_connection(self, *args: "Any", **kwargs: "Any") -> "Generator[Connection, None, None]":
         """Create and provide a database connection."""
         from adbc_driver_manager.dbapi import connect
 
