@@ -1,12 +1,11 @@
-from __future__ import annotations
-
 from contextlib import contextmanager
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Any, cast
+from typing import TYPE_CHECKING, Any, Union, cast
 
 from duckdb import DuckDBPyConnection
+from typing_extensions import NotRequired, TypedDict
 
-from sqlspec.base import GenericDatabaseConfig, NoPoolConfig
+from sqlspec.base import NoPoolSyncConfig
 from sqlspec.exceptions import ImproperConfigurationError
 from sqlspec.typing import Empty, EmptyType, dataclass_to_dict
 
@@ -17,8 +16,7 @@ if TYPE_CHECKING:
 __all__ = ("DuckDBConfig", "ExtensionConfig")
 
 
-@dataclass
-class ExtensionConfig:
+class ExtensionConfig(TypedDict):
     """Configuration for a DuckDB extension.
 
     This class provides configuration options for DuckDB extensions, including installation
@@ -29,44 +27,20 @@ class ExtensionConfig:
 
     name: str
     """The name of the extension to install"""
-    config: dict[str, Any] | None = None
+    config: "NotRequired[dict[str, Any]]"
     """Optional configuration settings to apply after installation"""
-    force_install: bool = False
+    force_install: "NotRequired[bool]"
     """Whether to force reinstall if already present"""
-    repository: str | None = None
+    repository: "NotRequired[str]"
     """Optional repository name to install from"""
-    repository_url: str | None = None
+    repository_url: "NotRequired[str]"
     """Optional repository URL to install from"""
-    version: str | None = None
+    version: "NotRequired[str]"
     """Optional version of the extension to install"""
 
-    @classmethod
-    def from_dict(cls, name: str, config: dict[str, Any] | bool | None = None) -> ExtensionConfig:
-        """Create an ExtensionConfig from a configuration dictionary.
-
-        Args:
-            name: The name of the extension
-            config: Configuration dictionary that may contain settings
-
-        Returns:
-            A new ExtensionConfig instance
-        """
-        if config is None:
-            return cls(name=name)
-
-        if not isinstance(config, dict):
-            config = {"force_install": bool(config)}
-
-        install_args = {
-            key: config.pop(key)
-            for key in ["force_install", "repository", "repository_url", "version", "config", "name"]
-            if key in config
-        }
-        return cls(name=name, **install_args)
-
 
 @dataclass
-class DuckDBConfig(NoPoolConfig[DuckDBPyConnection], GenericDatabaseConfig):
+class DuckDBConfig(NoPoolSyncConfig[DuckDBPyConnection]):
     """Configuration for DuckDB database connections.
 
     This class provides configuration options for DuckDB database connections, wrapping all parameters
@@ -75,28 +49,24 @@ class DuckDBConfig(NoPoolConfig[DuckDBPyConnection], GenericDatabaseConfig):
     For details see: https://duckdb.org/docs/api/python/overview#connection-options
     """
 
-    database: str | EmptyType = Empty
+    database: "Union[str, EmptyType]" = Empty
     """The path to the database file to be opened. Pass ":memory:" to open a connection to a database that resides in RAM instead of on disk. If not specified, an in-memory database will be created."""
 
-    read_only: bool | EmptyType = Empty
+    read_only: "Union[bool, EmptyType]" = Empty
     """If True, the database will be opened in read-only mode. This is required if multiple processes want to access the same database file at the same time."""
 
-    config: dict[str, Any] | EmptyType = Empty
+    config: "Union[dict[str, Any], EmptyType]" = Empty
     """A dictionary of configuration options to be passed to DuckDB. These can include settings like 'access_mode', 'max_memory', 'threads', etc.
 
     For details see: https://duckdb.org/docs/api/python/overview#connection-options
     """
 
-    extensions: Sequence[ExtensionConfig] | EmptyType = Empty
+    extensions: "Union[Sequence[ExtensionConfig], ExtensionConfig, EmptyType]" = Empty
     """A sequence of extension configurations to install and configure upon connection creation."""
 
     def __post_init__(self) -> None:
         """Post-initialization validation and processing.
 
-        This method handles merging extension configurations from both the extensions field
-        and the config dictionary, if present. The config['extensions'] field can be either:
-        - A dictionary mapping extension names to their configurations
-        - A list of extension names (which will be installed with force_install=True)
 
         Raises:
             ImproperConfigurationError: If there are duplicate extension configurations.
@@ -106,56 +76,81 @@ class DuckDBConfig(NoPoolConfig[DuckDBPyConnection], GenericDatabaseConfig):
 
         if self.extensions is Empty:
             self.extensions = []
+        if isinstance(self.extensions, dict):
+            self.extensions = [self.extensions]
         # this is purely for mypy
         assert isinstance(self.config, dict)  # noqa: S101
         assert isinstance(self.extensions, list)  # noqa: S101
+        config_exts: list[ExtensionConfig] = self.config.pop("extensions", [])
+        if not isinstance(config_exts, list):  # pyright: ignore[reportUnnecessaryIsInstance]
+            config_exts = [config_exts]  # type: ignore[unreachable]
 
-        _e = self.config.pop("extensions", {})
-        if not isinstance(_e, (dict, list, tuple)):
+        try:
+            if (
+                len(set({ext["name"] for ext in config_exts}).intersection({ext["name"] for ext in self.extensions}))
+                > 0
+            ):  # pyright: ignore[ reportUnknownArgumentType]
+                msg = "Configuring the same extension in both 'extensions' and as a key in 'config['extensions']' is not allowed.  Please use only one method to configure extensions."
+                raise ImproperConfigurationError(msg)
+        except (KeyError, TypeError) as e:
             msg = "When configuring extensions in the 'config' dictionary, the value must be a dictionary or sequence of extension names"
-            raise ImproperConfigurationError(msg)
-        if not isinstance(_e, dict):
-            _e = {str(ext): {"force_install": False} for ext in _e}  # pyright: ignore[reportUnknownVariableType,reportUnknownArgumentType]
+            raise ImproperConfigurationError(msg) from e
+        self.extensions.extend(config_exts)
 
-        if len(set(_e.keys()).intersection({ext.name for ext in self.extensions})) > 0:  # pyright: ignore[ reportUnknownArgumentType]
-            msg = "Configuring the same extension in both 'extensions' and as a key in 'config['extensions']' is not allowed"
-            raise ImproperConfigurationError(msg)
+    def _configure_connection(self, connection: "DuckDBPyConnection") -> None:
+        """Configure the connection.
 
-        self.extensions.extend([ExtensionConfig.from_dict(name, ext_config) for name, ext_config in _e.items()])  # pyright: ignore[reportUnknownArgumentType,reportUnknownVariableType]
+        Args:
+            connection: The DuckDB connection to configure.
+        """
+        for config in cast("list[str]", self.config):
+            connection.execute(config)
 
-    def _configure_extensions(self, connection: DuckDBPyConnection) -> None:
+    def _configure_extensions(self, connection: "DuckDBPyConnection") -> None:
         """Configure extensions for the connection.
 
         Args:
             connection: The DuckDB connection to configure extensions for.
 
-        Raises:
-            ImproperConfigurationError: If extension installation or configuration fails.
+
         """
         if self.extensions is Empty:
             return
 
         for extension in cast("list[ExtensionConfig]", self.extensions):
-            try:
-                if extension.force_install:
-                    connection.install_extension(
-                        extension=extension.name,
-                        force_install=extension.force_install,
-                        repository=extension.repository,
-                        repository_url=extension.repository_url,
-                        version=extension.version,
-                    )
-                connection.load_extension(extension.name)
+            self._configure_extension(connection, extension)
 
-                if extension.config:
-                    for key, value in extension.config.items():
-                        connection.execute(f"SET {key}={value}")
-            except Exception as e:
-                msg = f"Failed to configure extension {extension.name}. Error: {e!s}"
-                raise ImproperConfigurationError(msg) from e
+    @staticmethod
+    def _configure_extension(connection: "DuckDBPyConnection", extension: ExtensionConfig) -> None:
+        """Configure a single extension for the connection.
+
+        Args:
+            connection: The DuckDB connection to configure extension for.
+            extension: The extension configuration to apply.
+
+        Raises:
+            ImproperConfigurationError: If extension installation or configuration fails.
+        """
+        try:
+            if extension.get("force_install"):
+                connection.install_extension(
+                    extension=extension["name"],
+                    force_install=extension.get("force_install", False),
+                    repository=extension.get("repository"),
+                    repository_url=extension.get("repository_url"),
+                    version=extension.get("version"),
+                )
+            connection.load_extension(extension["name"])
+
+            if extension.get("config"):
+                for key, value in extension.get("config", {}).items():
+                    connection.execute(f"SET {key}={value}")
+        except Exception as e:
+            msg = f"Failed to configure extension {extension['name']}. Error: {e!s}"
+            raise ImproperConfigurationError(msg) from e
 
     @property
-    def connection_config_dict(self) -> dict[str, Any]:
+    def connection_config_dict(self) -> "dict[str, Any]":
         """Return the connection configuration as a dict.
 
         Returns:
@@ -166,7 +161,7 @@ class DuckDBConfig(NoPoolConfig[DuckDBPyConnection], GenericDatabaseConfig):
             config["database"] = ":memory:"
         return config
 
-    def create_connection(self) -> DuckDBPyConnection:
+    def create_connection(self) -> "DuckDBPyConnection":
         """Create and return a new database connection with configured extensions.
 
         Returns:
@@ -180,20 +175,21 @@ class DuckDBConfig(NoPoolConfig[DuckDBPyConnection], GenericDatabaseConfig):
         try:
             connection = duckdb.connect(**self.connection_config_dict)  # pyright: ignore[reportUnknownMemberType]
             self._configure_extensions(connection)
-            return connection
+            self._configure_connection(connection)
         except Exception as e:
             msg = f"Could not configure the DuckDB connection. Error: {e!s}"
             raise ImproperConfigurationError(msg) from e
+        else:
+            return connection
 
     @contextmanager
-    def provide_connection(self, *args: Any, **kwargs: Any) -> Generator[DuckDBPyConnection, None, None]:
+    def provide_connection(self, *args: Any, **kwargs: Any) -> "Generator[DuckDBPyConnection, None, None]":
         """Create and provide a database connection.
 
         Yields:
             A DuckDB connection instance.
 
-        Raises:
-            ImproperConfigurationError: If the connection could not be established.
+
         """
         connection = self.create_connection()
         try:
